# -*- coding: utf-8 -*-

"""
Module for sen2cor processings.
"""

import logging
import pathlib
import subprocess
from typing import Union

from .config import Config


logger = logging.getLogger(__name__)
logging.basicConfig(level=logging.INFO)


def process_sen2cor(
        l1c_product_path: Union[str, pathlib.PosixPath],
        resolution: int = 10
) -> None:
    """Process a L1C SAFE folder using sen2cor thanks to a subprocess call.
    The sen2cor bashrc file must be specified in the sen2chain configuration.

    :param l1c_product_path: path to the L1C SAFE folder.
    :param resolution: resolution to process.
    """
    # workaround for sen2cor 2.5.5 crash
    # 20 m resolution bands must be processed before 10 m
    # see: https://forum.step.esa.int/t/problem-with-sen2cor-2-5-5-version/10324/20

    # TODO: Add 60m resolution.

    sen2cor_bashrc_path = Config().get("sen2cor_bashrc_path")

    if resolution == 10:

        logger.info("sen2cor processing 20 m: {}".format(l1c_product_path))
        command1 = "/bin/bash, -i, -c, source {sen2cor_bashrc} && L2A_Process --resolution {res} {l1c_folder}".format(
            sen2cor_bashrc=str(sen2cor_bashrc_path),
            res=20,
            l1c_folder=str(l1c_product_path)
            )

        process1 = subprocess.run(command1.split(", "))

        logger.info("sen2cor processing 10 m: {}".format(l1c_product_path))
        command2 = "/bin/bash, -i, -c, source {sen2cor_bashrc} && L2A_Process --resolution {res} {l1c_folder}".format(
            sen2cor_bashrc=str(sen2cor_bashrc_path),
            res=10,
            l1c_folder=str(l1c_product_path)
            )
        process2 = subprocess.run(command2.split(", "))

    else:
        logger.debug("sen2cor processing: {}".format(l1c_product_path))
        command = "/bin/bash, -i, -c, source {sen2cor_bashrc} && L2A_Process --resolution {resolution} {l1c_folder}".format(
            sen2cor_bashrc=str(sen2cor_bashrc_path),
            resolution=resolution,
            l1c_folder=str(l1c_product_path)
            )
        process = subprocess.run(command.split(", "))
